<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPCpop_Ajax' )) {

    class IPCpop_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'ipcpop_update'       => 'update',
            'ipcpop_delete'       => 'delete',
            'ipcpop_setting'      => 'setting',
            'ipcpop_getoptin'     => 'get_optin',
            'ipcpop_getchart'     => 'get_chart',
            'ipcpop_savestat'     => 'save_stat'
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipcpop'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Update content
         *
         * @return void
         */
        public function update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['content_id'] )) {
                $contentId = absint( $_POST['content_id'] );
                if ( $content = get_post( $contentId ) ) {
                    $this->_update_content( $content );
                } else {
                    $contentId = 0;
                }
            } else {
                $contentId = $this->_add_content();
            }
            if ( $contentId )
            {
                $error = false;
                $model = new IPCpop_Model();
                $model->save_setting( $contentId );
            }
            if ( $error ) {
                $status  = 0;
                $contentId = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a content popup.', 'wp-popper-pro' );
                } else {
                    $message = __( 'Failed to save content popup.', 'wp-popper-pro' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a content popup.', 'wp-popper-pro' );
                    $redirect = admin_url() . 'admin.php?page=ipcpop&action=update&id=' . $contentId . '&create=1';
                } else {
                    $message = __( 'Content popup successfully saved.', 'wp-popper-pro' );
                }
            }
            $result = array(
                'status'     => $status,
                'message'    => $message,
                'contentid'  => $contentId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new content
         *
         * @return int
         */
        protected function _add_content()
        {
            global $user_ID;
            
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $status = 'publish';
            if ( ! empty( $_POST['status'] ) && ( $_POST['status'] == 'false' || $_POST['status'] == false ) ) {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'ipcpop-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update content
         *
         * @param  object $content
         * @return boolean
         */
        protected function _update_content( $content )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $content->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $status = 'publish';
            if ( ! empty( $_POST['status'] ) && ( $_POST['status'] == 'false' || $_POST['status'] == false ) ) {
                $status = 'draft';
            }
            $dataPost['post_status'] = $status;
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $content->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete content
         *
         * @return void
         */
        public function delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp-popper-pro' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the content popup', 'wp-popper-pro' ),
                    'redirect' => admin_url() . 'admin.php?page=ipcpop&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the content popup', 'wp-popper-pro' )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( isset( $_POST['slug'] )) 
            {
                $slug = apply_filters( 'pre_term_name', $_POST['slug'] );
                update_option( '__ipcpop_slug', $slug );
            }
            if ( isset( $_POST['schema_shortcode'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['schema_shortcode'] );
                update_option( '__ipcpop_schema_shortcode', $value );
            }
            if ( isset( $_POST['schema_widget'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['schema_widget'] );
                update_option( '__ipcpop_schema_widget', $value );
            }
            if ( isset( $_POST['schema_page'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['schema_page'] );
                update_option( '__ipcpop_schema_page', $value );
            }
            if ( isset( $_POST['group_as_product'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['group_as_product'] );
                update_option( '__ipcpop_group_as_product', $value );
            }
            if ( isset( $_POST['product_name'] )) 
            {
                $value = apply_filters( 'single_post_title', $_POST['product_name'] );
                update_option( '__ipcpop_product_name', $value );
            }
            if ( isset( $_POST['gravatar'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['gravatar'] );
                update_option( '__ipcpop_gravatar', $value );
            }
            
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update testimonial settings.', 'wp-popper-pro' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully updated testimony settings.', 'wp-popper-pro' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Get responder data
         *
         * @return void
         */
        public function get_optin()
        {
            if ( ! empty( $_POST['html'] ))
            {
                $html = str_replace( "'", '"', $_POST['html'] );
                $data = IPCpop_Form::parse( $html );
                echo json_encode( array(
                    'status'    => 1,
                    'data'      => $data
                ) );
                die();
            }
            echo json_encode( array(
                'status'  => 0
            ) );
            die();
        }
        
        /**
         * Get chart
         *
         * @return void
         */
        public function get_chart()
        {
            $data = array_merge( $_POST, $_GET );
            if ( ! empty( $data['pageid'] ) && ! empty( $data['type'] )) 
            {
                $pageid    = absint( $data['pageid'] );
                $type      = apply_filters( 'pre_term_name', $data['type'] );
                $dateStart = false;
                $dateEnd   = false;
                if ( ! empty( $data['start'] ) && ! empty( $data['end'] )) {
                    $timeEnd   = strtotime( $data['end'] );
                    $timeStart = strtotime( $data['start'] );
                    $dateStart = gmdate("Y-m-d", $timeStart);
                    $dateEnd   = gmdate("Y-m-d", $timeEnd);
                }
                $model     = new IPCpop_Model();
                $chart     = array();
                $results   = $model->get_statistic_data( $pageid, $type, $dateStart, $dateEnd );
                
                if ( ! empty( $results )) {
                    foreach( $results as $data ) {
                        $timestamp = strtotime( $data->gdate );
                        $phpdate   = getdate($timestamp);
                        if ( $type == 'ctr' ) {
                            $value = 0;
                            if ( ! empty( $data->click ) && ! empty( $data->view )) {
                                $rate  = 100 * intval($data->click) / intval($data->view);
                                $rate  = round( $rate, 2 );
                                $value = $rate;
                            }
                        } else {
                            $value = (int)$data->value;
                        }
                        $chart[] = array(
                            'value'    => $value,
                            'year'     => $phpdate['year'],
                            'mon'      => $phpdate['mon'] - 1,
                            'day'      => $phpdate['mday'],
                        );
                    }
                }
                if ( $type == 'view' ) {
                    $label = __( 'Views', 'wp-popper-pro' );
                } elseif ( $type == 'subscribe' ) {
                    $label = __( 'Subscribes', 'wp-popper-pro' );
                } elseif ( $type == 'social' ) {
                    $label = __( 'Social Button Clicks', 'wp-popper-pro' );
                } elseif ( $type == 'buy' ) {
                    $label = __( 'Buy Button Clicks', 'wp-popper-pro' );
                } else {
                    $label = __( 'Data', 'wp-popper-pro' );
                }
                echo json_encode( array(
                    'status'            => 1,
                    'labelDate'         => __( 'Date', 'wp-popper-pro' ),
                    'labelValue'        => $label,
                    'data'              => $chart
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save statistic data
         *
         * @return void
         */
        public function save_stat()
        {
            $error = true;
            if ( ! empty( $_POST['page_id'] ) && ! empty( $_POST['type'] )) 
            {
                $page_id = absint( $_POST['page_id'] );
                if ( $page = get_post( $page_id ))
                {
                    $type  = apply_filters( 'pre_term_name', $_POST['type'] );
                    $model = new IPCpop_Model();
                    $model->save_stat( $page, $type );
                    
                    $error = false;
                }
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to save statistic data.', 'wp-popper-pro' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to save statistic data.', 'wp-popper-pro' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
    }
}