<?php
if ( ! class_exists( 'IPCpop_Shortcode' )) {

    /**
     * Class for handling administrator page
     */
    class IPCpop_Shortcode
    {
        /**
         * Show content editor
         *
         * @return void
         */
        public function editor()
        {
            $path = IPCPOP_PATH . 'app/views/admin/shortcode.php';
            //
            //Include editor
            include( $path );
        }
        
        /**
         * Create shortcode content
         *
         * @param  array  $atts
         * @return string
         */
        public function render( $atts )
        {
            global $user_ID;
            
            if ( empty( $atts['content'] )) {
                return '';
            }
            //
            //Get content
            $content_id = absint( $atts['content'] );
            if ( ! $content = get_post( $content_id )) {
                return '';
            }
            //
            //Check post status
            if ( $content->post_status != 'publish' ) {
                return '';
            }
            $this->content = $content;
            $this->setting = new IPCpop_Setting( $content_id, '__ipcpop-setting' );
            $this->args    = $atts;
            
            //
            //Check restricted
            if ( $this->setting->getSetting( 'restricted', 'false' ) == 'true' ){
                if ( empty( $user_ID )) {
                    return '';
                }
            }
            
            //
            //Include view
            ob_start();
            $path = IPCPOP_PATH . 'app/views/public/main.php';
            include( $path );
            $output  = ob_get_contents();
            ob_end_clean();
            return $output;
        }
        
        /**
         * Get public view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPCPOP_PATH . 'app/views/public/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get main class
         *
         * @return string
         */
        public function get_main_class()
        {
            $sett  = $this->setting;
            $class = '';
            //
            //Border radius
            $radius = $sett->getSetting( 'border_radius', 'none' );
            $class .= 'ipcpop_radius_' . $radius;
            return $class;
        }
        
        /**
         * Get main style
         *
         * @return string
         */
        public function get_main_style()
        {
            $sett  = $this->setting;
            $style = '';
            //
            //Background color
            if ( $bgcolor = $sett->getSetting( 'bgcolor' ) ) {
                $style .= 'background-color:' . $bgcolor . ';';
            }
            //
            //Background image
            if ( $bgimage = $sett->getSetting( 'background_image' ) ) {
                $data   = wp_get_attachment_image_src( $bgimage, 'full' );
                $src    = $data[0];
                $style .= "background-image:url('" . $src . "');";
            }
            //
            //Background repeat
            $bgrepeat = $sett->getSetting( 'background_repeat', 'none' );
            $style   .= 'background-repeat:' . $bgrepeat . ';';
            //
            //Color
            if ( $color = $sett->getSetting( 'color' ) ) {
                $style .= 'color:' . $color . ';';
            }
            //
            //Font size
            $size   = $sett->getSetting( 'font_size', 14 );
            $style .= 'font-size:' . $size . ';';
            //
            //Font family
            $family_name = $sett->getSetting( 'font_family', 'roboto' );
            $font_family = IPCpop_Font::getFontName( $family_name );
            $style  .= 'font-family:' . $font_family . ';';
            //Border
            $bosize  = $sett->getSetting( 'border_width' );
            if ( ! empty( $bosize )) {
                $bocolor = $sett->getSetting( 'border_color', '#dddddd' );
                $bostyle = $sett->getSetting( 'border_style', 'solid' );
                $style  .= 'border:' . $bosize . 'px ' . $bostyle . ' ' . $bocolor . ';';
            }
            return $style;
        }
        
        /**
         * Fix youtube url
         *
         * @param  string $url
         * @return string
         */
        public function fix_youtube_url( $url )
        {
            if ( $url )
            {
                if ( strpos( $url, 'embed' ) === false ) {
                    if ( strpos( $url, 'watch' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['query'] )) {
                            parse_str( $parsed['query'], $args );
                            if ( ! empty( $args['v'] )) {
                                $id = $args['v'];
                            }
                        }
                        $url = 'http://youtube.com/embed/' . $id;
                    
                    } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['path'] )) {
                            $id = trim( $parsed['path'], '/' );
                        }
                        $url = 'http://youtube.com/embed/' . $id;
                    
                    }
                }
                $url .= '?rel=0';
            }
            return $url;
        }
        
        /**
         * Get video duration
         *
         * @param  string $url
         * @return string
         */
        public function get_video_duration( $url )
        {
            $duration = 0;
            if ( $url )
            {
                $id = $this->get_video_id( $url );
                if ( ! empty( $id )) {
                    $request = 'http://gdata.youtube.com/feeds/api/videos/'.$id.'?v=2&alt=jsonc';
                    $data = @file_get_contents( $request );
                    if ( $data !== false ) {
                        $obj = json_decode( $data );
                        $duration = $obj->data->duration; 
                    }   
                }
            }
            return $duration;
        }
        
        /**
         * Get video id
         *
         * @param  string $url
         * @return string
         */
        public function get_video_id( $url )
        {
            $id = '';
            if ( strpos( $url, 'embed' ) === false ) {
                if ( strpos( $url, 'watch' ) !== false ) {
                    $parsed = parse_url( $url );
                    if ( ! empty( $parsed['query'] )) {
                        parse_str( $parsed['query'], $args );
                        if ( ! empty( $args['v'] )) {
                            $id = $args['v'];
                        }
                    }
                } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                    $parsed = parse_url( $url );
                    if ( ! empty( $parsed['path'] )) {
                        $id = trim( $parsed['path'], '/' );
                    }
                }
            } else {
                $parsed = parse_url( $url );
                if ( ! empty( $parsed['path'] )) {
                    $id = str_replace( 'embed/', '', $parsed['path'] );
                }
            }
            return $id;
        }
    }
}