<?php
if ( ! class_exists( 'IPCpop_Model' )) {

    /**
     * Class for manage content popup setting
     */
    class IPCpop_Model
    {
        /**
         * Save setting content
         *
         * @param  int $contentId
         * @return void
         */
        public function save_add_setting( $contentId )
        {
            $contentId = absint( $contentId );
            $data      = $this->_get_add_setting_data();
            $setting   = new IPCpop_Setting( $contentId, '__ipcpop-setting' );
            $result    = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get add setting data
         *
         * @return array
         */
        protected function _get_add_setting_data()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
            
            /**
             * General
             */
            if ( isset( $data['type'] )) {
                $setting['type'] = apply_filters( 'pre_term_name', $data['type'] );
            }
            return $setting;
        }
        
        /**
         * Save setting bar
         *
         * @param  int $barId
         * @return void
         */
        public function save_setting( $barId )
        {
            $barId   = absint( $barId );
            $data    = $this->_get_setting_data();
            $setting = new IPCpop_Setting( $barId, '__ipcpop-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _get_setting_data()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
            
            /**
             * General
             */
            if ( isset( $data['type'] )) {
                $setting['type'] = apply_filters( 'pre_term_name', $data['type'] );
            }
            if ( isset( $data['restricted'] )) {
                $setting['restricted'] = apply_filters( 'pre_term_name', $data['restricted'] );
            }
            
            /**
             * Content
             */
            
            //
            //Video
            if ( isset( $data['video_title'] )) {
                $setting['video_title'] = apply_filters( 'single_post_title', $data['video_title'] );
            }
            if ( isset( $data['video_info'] )) {
                $setting['video_info'] = $data['video_info'];
            }
            if ( isset( $data['video_url'] )) {
                $setting['video_url'] = apply_filters( 'pre_link_url', $data['video_url'] );
            }
            if ( isset( $data['video_redirect_url'] )) {
                $setting['video_redirect_url'] = apply_filters( 'pre_link_url', $data['video_redirect_url'] );
            }
            if ( isset( $data['video_width'] )) {
                $setting['video_width'] = absint( $data['video_width'] );
            }
            if ( isset( $data['video_height'] )) {
                $setting['video_height'] = absint( $data['video_height'] );
            }
            if ( isset( $data['video_autoplay'] )) {
                $setting['video_autoplay'] = apply_filters( 'pre_term_name', $data['video_autoplay'] );
            }
            
            //
            //Image
            if ( isset( $data['image_title'] )) {
                $setting['image_title'] = apply_filters( 'single_post_title', $data['image_title'] );
            }
            if ( isset( $data['image_info'] )) {
                $setting['image_info'] = $data['image_info'];
            }
            if ( isset( $data['image_url'] )) {
                $setting['image_url'] = apply_filters( 'pre_link_url', $data['image_url'] );
            }
            if ( isset( $data['image_file'] )) {
                $setting['image_file'] = absint( $data['image_file'] );
            }
            if ( isset( $data['image_newtab'] )) {
                $setting['image_newtab'] = apply_filters( 'pre_term_name', $data['image_newtab'] );
            }
            
            //
            //Text
            if ( isset( $data['text_content'] )) {
                $setting['text_content'] = $data['text_content'];
            }
            
            //
            //Product
            if ( isset( $data['product_title'] )) {
                $setting['product_title'] = apply_filters( 'single_post_title', $data['product_title'] );
            }
            if ( isset( $data['product_info'] )) {
                $setting['product_info'] = $data['product_info'];
            }
            if ( isset( $data['product_url'] )) {
                $setting['product_url'] = apply_filters( 'pre_link_url', $data['product_url'] );
            }
            if ( isset( $data['product_image'] )) {
                $setting['product_image'] = absint( $data['product_image'] );
            }
            if ( isset( $data['product_price'] )) {
                $setting['product_price'] = apply_filters( 'single_post_title', $data['product_price'] );
            }
            if ( isset( $data['product_button'] )) {
                $setting['product_button'] = apply_filters( 'single_post_title', $data['product_button'] );
            }
            
            //
            //Article
            if ( isset( $data['article_title'] )) {
                $setting['article_title'] = apply_filters( 'single_post_title', $data['article_title'] );
            }
            if ( isset( $data['article_subtitle'] )) {
                $setting['article_subtitle'] = apply_filters( 'single_post_title', $data['article_subtitle'] );
            }
            if ( isset( $data['article_content'] )) {
                $setting['article_content'] = $data['article_content'];
            }
            if ( isset( $data['article_url'] )) {
                $setting['article_url'] = apply_filters( 'pre_link_url', $data['article_url'] );
            }
            if ( isset( $data['article_image'] )) {
                $setting['article_image'] = absint( $data['article_image'] );
            }
            if ( isset( $data['article_button'] )) {
                $setting['article_button'] = apply_filters( 'single_post_title', $data['article_button'] );
            }
            
            //
            //Profile
            if ( isset( $data['profile_name'] )) {
                $setting['profile_name'] = apply_filters( 'single_post_title', $data['profile_name'] );
            }
            if ( isset( $data['profile_info'] )) {
                $setting['profile_info'] = apply_filters( 'single_post_title', $data['profile_info'] );
            }
            if ( isset( $data['profile_content'] )) {
                $setting['profile_content'] = $data['profile_content'];
            }
            if ( isset( $data['profile_url'] )) {
                $setting['profile_url'] = apply_filters( 'pre_link_url', $data['profile_url'] );
            }
            if ( isset( $data['profile_photo'] )) {
                $setting['profile_photo'] = absint( $data['profile_photo'] );
            }
            if ( isset( $data['profile_button'] )) {
                $setting['profile_button'] = apply_filters( 'single_post_title', $data['profile_button'] );
            }
            if ( isset( $data['profile_facebook'] )) {
                $setting['profile_facebook'] = apply_filters( 'pre_link_url', $data['profile_facebook'] );
            }
            if ( isset( $data['profile_twitter'] )) {
                $setting['profile_twitter'] = apply_filters( 'pre_link_url', $data['profile_twitter'] );
            }
            if ( isset( $data['profile_google_plus'] )) {
                $setting['profile_google_plus'] = apply_filters( 'pre_link_url', $data['profile_google_plus'] );
            }
            if ( isset( $data['profile_linkedin'] )) {
                $setting['profile_linkedin'] = apply_filters( 'pre_link_url', $data['profile_linkedin'] );
            }
            if ( isset( $data['profile_pinterest'] )) {
                $setting['profile_pinterest'] = apply_filters( 'pre_link_url', $data['profile_pinterest'] );
            }
            
            /**
             * Design
             */
            if ( isset( $data['bgcolor'] )) {
                $setting['bgcolor'] = apply_filters( 'pre_term_name', $data['bgcolor'] );
            }
            if ( isset( $data['color'] )) {
                $setting['color'] = apply_filters( 'pre_term_name', $data['color'] );
            }
            if ( isset( $data['background_image'] )) {
                $setting['background_image'] = absint( $data['background_image'] );
            }
            if ( isset( $data['background_repeat'] )) {
                $setting['background_repeat'] = apply_filters( 'pre_term_name', $data['background_repeat'] );
            }
            if ( isset( $data['border_width'] )) {
                $setting['border_width'] = apply_filters( 'pre_term_name', $data['border_width'] );
            }
            if ( isset( $data['border_color'] )) {
                $setting['border_color'] = apply_filters( 'pre_term_name', $data['border_color'] );
            }
            if ( isset( $data['border_style'] )) {
                $setting['border_style'] = apply_filters( 'pre_term_name', $data['border_style'] );
            }
            if ( isset( $data['border_radius'] )) {
                $setting['border_radius'] = apply_filters( 'pre_term_name', $data['border_radius'] );
            }
            if ( isset( $data['font_size'] )) {
                $setting['font_size'] = absint( $data['font_size'] );
            }
            if ( isset( $data['font_family'] )) {
                $setting['font_family'] = apply_filters( 'single_post_title', $data['font_family'] );
            }
            if ( isset( $data['close_icon'] )) {
                $setting['close_icon'] = apply_filters( 'pre_term_name', $data['close_icon'] );
            }
            if ( isset( $data['close_color'] )) {
                $setting['close_color'] = apply_filters( 'pre_term_name', $data['close_color'] );
            }
            
            //Design article 
            if ( isset( $data['article_content_style'] )) {
                $setting['article_content_style'] = apply_filters( 'pre_term_name', $data['article_content_style'] );
            }
            if ( isset( $data['article_button_style'] )) {
                $setting['article_button_style'] = apply_filters( 'pre_term_name', $data['article_button_style'] );
            }
            if ( isset( $data['article_button_color'] )) {
                $setting['article_button_color'] = apply_filters( 'pre_term_name', $data['article_button_color'] );
            }
            if ( isset( $data['article_button_size'] )) {
                $setting['article_button_size'] = apply_filters( 'pre_term_name', $data['article_button_size'] );
            }
            
            //Design product 
            if ( isset( $data['product_content_style'] )) {
                $setting['product_content_style'] = apply_filters( 'pre_term_name', $data['product_content_style'] );
            }
            if ( isset( $data['product_button_style'] )) {
                $setting['product_button_style'] = apply_filters( 'pre_term_name', $data['product_button_style'] );
            }
            if ( isset( $data['product_button_color'] )) {
                $setting['product_button_color'] = apply_filters( 'pre_term_name', $data['product_button_color'] );
            }
            if ( isset( $data['product_button_size'] )) {
                $setting['product_button_size'] = apply_filters( 'pre_term_name', $data['product_button_size'] );
            }
            
            //Design profile 
            if ( isset( $data['profile_content_style'] )) {
                $setting['profile_content_style'] = apply_filters( 'pre_term_name', $data['profile_content_style'] );
            }
            if ( isset( $data['profile_button_style'] )) {
                $setting['profile_button_style'] = apply_filters( 'pre_term_name', $data['profile_button_style'] );
            }
            if ( isset( $data['profile_button_color'] )) {
                $setting['profile_button_color'] = apply_filters( 'pre_term_name', $data['profile_button_color'] );
            }
            if ( isset( $data['profile_button_size'] )) {
                $setting['profile_button_size'] = apply_filters( 'pre_term_name', $data['profile_button_size'] );
            }
            if ( isset( $data['profile_social_style'] )) {
                $setting['profile_social_style'] = apply_filters( 'pre_term_name', $data['profile_social_style'] );
            }
            
            //
            //Secodary Box
            if ( isset( $data['box_bgcolor'] )) {
                $setting['box_bgcolor'] = apply_filters( 'pre_term_name', $data['box_bgcolor'] );
            }
            if ( isset( $data['box_color'] )) {
                $setting['box_color'] = apply_filters( 'pre_term_name', $data['box_color'] );
            }
            if ( isset( $data['box_border_width'] )) {
                $setting['box_border_width'] = apply_filters( 'pre_term_name', $data['box_border_width'] );
            }
            if ( isset( $data['box_border_color'] )) {
                $setting['box_border_color'] = apply_filters( 'pre_term_name', $data['box_border_color'] );
            }
            if ( isset( $data['box_border_style'] )) {
                $setting['box_border_style'] = apply_filters( 'pre_term_name', $data['box_border_style'] );
            }
            if ( isset( $data['box_border_radius'] )) {
                $setting['box_border_radius'] = apply_filters( 'pre_term_name', $data['box_border_radius'] );
            }
            if ( isset( $data['box_font_size'] )) {
                $setting['box_font_size'] = absint( $data['box_font_size'] );
            }
            if ( isset( $data['box_font_family'] )) {
                $setting['box_font_family'] = apply_filters( 'single_post_title', $data['box_font_family'] );
            }
            
            //
            //Form design
            if ( isset( $data['form_layout'] )) {
                $setting['form_layout'] = apply_filters( 'pre_term_name', $data['form_layout'] );
            }
            if ( isset( $data['form_bgcolor'] )) {
                $setting['form_bgcolor'] = apply_filters( 'pre_term_name', $data['form_bgcolor'] );
            }
            if ( isset( $data['form_color'] )) {
                $setting['form_color'] = apply_filters( 'pre_term_name', $data['form_color'] );
            }
            if ( isset( $data['form_border_width'] )) {
                $setting['form_border_width'] = apply_filters( 'pre_term_name', $data['form_border_width'] );
            }
            if ( isset( $data['form_border_color'] )) {
                $setting['form_border_color'] = apply_filters( 'pre_term_name', $data['form_border_color'] );
            }
            if ( isset( $data['form_border_style'] )) {
                $setting['form_border_style'] = apply_filters( 'pre_term_name', $data['form_border_style'] );
            }
            if ( isset( $data['form_border_radius'] )) {
                $setting['form_border_radius'] = apply_filters( 'pre_term_name', $data['form_border_radius'] );
            }
            if ( isset( $data['form_font_size'] )) {
                $setting['form_font_size'] = absint( $data['form_font_size'] );
            }
            if ( isset( $data['form_font_family'] )) {
                $setting['form_font_family'] = apply_filters( 'single_post_title', $data['form_font_family'] );
            }
            if ( isset( $data['form_button_style'] )) {
                $setting['form_button_style'] = apply_filters( 'pre_term_name', $data['form_button_style'] );
            }
            if ( isset( $data['form_button_color'] )) {
                $setting['form_button_color'] = apply_filters( 'pre_term_name', $data['form_button_color'] );
            }
            if ( isset( $data['form_button_size'] )) {
                $setting['form_button_size'] = apply_filters( 'pre_term_name', $data['form_button_size'] );
            }
            
            //
            //Effect
            //
            if ( isset( $data['content_effect'] )) {
                $setting['content_effect'] = apply_filters( 'pre_term_name', $data['content_effect'] );
            }
            if ( isset( $data['content_audio'] )) {
                $setting['content_audio'] = apply_filters( 'pre_term_name', $data['content_audio'] );
            }
            if ( isset( $data['box_effect'] )) {
                $setting['box_effect'] = apply_filters( 'pre_term_name', $data['box_effect'] );
            }
            if ( isset( $data['box_audio'] )) {
                $setting['box_audio'] = apply_filters( 'pre_term_name', $data['box_audio'] );
            }
            
            //
            //Form
            //
            if ( isset( $data['activate_second_popup'] )) {
                $setting['activate_second_popup'] = apply_filters( 'pre_term_name', $data['activate_second_popup'] );
            }
            if ( isset( $data['interval_display'] )) {
                $setting['interval_display'] = absint( $data['interval_display'] );
            }
            
            if ( isset( $data['activate_form'] )) {
                $setting['activate_form'] = apply_filters( 'pre_term_name', $data['activate_form'] );
            }
            if ( isset( $data['responder_title'] )) {
                $setting['responder_title'] = apply_filters( 'single_post_title', $data['responder_title'] );
            }
            if ( isset( $data['responder_info'] )) {
                $setting['responder_info'] = apply_filters( 'single_post_title', $data['responder_info'] );
            }
            if ( isset( $data['autoresponder_code'] )) {
                $setting['autoresponder_code'] = $data['autoresponder_code'];
            }
            if ( isset( $data['autoresponder_action'] )) {
                $setting['autoresponder_action'] = apply_filters( 'pre_link_url', $data['autoresponder_action'] );
            }
            if ( isset( $data['autoresponder_email'] )) {
                $setting['autoresponder_email'] = apply_filters( 'single_post_title', $data['autoresponder_email'] );
            }
            if ( isset( $data['autoresponder_email_label'] )) {
                $setting['autoresponder_email_label'] = apply_filters( 'single_post_title', $data['autoresponder_email_label'] );
            }
            if ( isset( $data['autoresponder_name'] )) {
                $setting['autoresponder_name'] = apply_filters( 'single_post_title', $data['autoresponder_name'] );
            }
            if ( isset( $data['autoresponder_name_label'] )) {
                $setting['autoresponder_name_label'] = apply_filters( 'single_post_title', $data['autoresponder_name_label'] );
            }
            if ( isset( $data['autoresponder_name_activate'] )) {
                $setting['autoresponder_name_activate'] = apply_filters( 'pre_term_name', $data['autoresponder_name_activate'] );
            }
            if ( isset( $data['autoresponder_form_label'] )) {
                $setting['autoresponder_form_label'] = apply_filters( 'pre_term_name', $data['autoresponder_form_label'] );
            }
            if ( isset( $data['autoresponder_button_text'] )) {
                $setting['autoresponder_button_text'] = apply_filters( 'single_post_title', $data['autoresponder_button_text'] );
            }
            if ( isset( $data['autoresponder_button_style'] )) {
                $setting['autoresponder_button_style'] = apply_filters( 'pre_term_name', $data['autoresponder_button_style'] );
            }
            
            //
            //Buy Button
            if ( isset( $data['activate_buy_button'] )) {
                $setting['activate_buy_button'] = apply_filters( 'pre_term_name', $data['activate_buy_button'] );
            }
            if ( isset( $data['buy_button_image'] )) {
                $setting['buy_button_image'] = absint( $data['buy_button_image'] );
            }
            if ( isset( $data['buy_button_url'] )) {
                $setting['buy_button_url'] = apply_filters( 'pre_link_url', $data['buy_button_url'] );
            }
            if ( isset( $data['buy_button_width'] )) {
                $setting['buy_button_width'] = absint( $data['buy_button_width'] );
            }
            if ( isset( $data['buy_button_height'] )) {
                $setting['buy_button_height'] = absint( $data['buy_button_height'] );
            }
            if ( isset( $data['buy_button_newtab'] )) {
                $setting['buy_button_newtab'] = apply_filters( 'pre_term_name', $data['buy_button_newtab'] );
            }
            
            //
            //Social
            if ( isset( $data['activate_social'] )) {
                $setting['activate_social'] = apply_filters( 'pre_term_name', $data['activate_social'] );
            }
            if ( isset( $data['social_style'] )) {
                $setting['social_style'] = apply_filters( 'pre_term_name', $data['social_style'] );
            }
            if ( isset( $data['social_size'] )) {
                $setting['social_size'] = apply_filters( 'pre_term_name', $data['social_size'] );
            }
            if ( isset( $data['social_align'] )) {
                $setting['social_align'] = apply_filters( 'pre_term_name', $data['social_align'] );
            }
            $socials = array(
                'facebook'      => 'Facebook',
                'twitter'       => 'Twitter',
                'linkedin'      => 'LinkedIn',
                'google-plus'   => 'Google+',
                'youtube'       => 'Youtube',
                'flickr'        => 'Flickr',
                'pinterest'     => 'Pinterest',
                'instagram'     => 'Instagram',
                'vimeo'         => 'Vimeo',
                'tumblr'        => 'Tumblr',
                'behance'       => 'Behance',
                'dribbble'      => 'Dribbble'
            );
            foreach( $socials as $social_name => $social_title )
            {
                $key = 'social_' . $social_name . '_url';
                if ( isset( $data[$key] )) {
                    $setting[$key] = apply_filters( 'pre_link_url', $data[$key] );
                }
                $key = 'social_' . $social_name . '_on';
                if ( isset( $data[$key] )) {
                    $setting[$key] = apply_filters( 'pre_term_name', $data[$key] );
                }
            }
            
            return $setting;
        }
        
        /**
         * Get stats
         *
         * @return array
         */
        public function get_stats()
        {
            global $wpdb;
            
            $table = $wpdb->prefix . 'iptee_stats';
            $sql   = "
                SELECT *
                FROM `$table`
            ";
            $results = $wpdb->get_row( $sql );
            return $results;
        }
        
        /**
         * Get stat
         *
         * @param  int $stat_id
         * @return array
         */
        public function get_stat( $stat_id )
        {
            global $wpdb;
            
            $stat_id = absint( $stat_id );
            $table   = $wpdb->prefix . 'iptee_stats';
            $sql     = "
                SELECT *
                FROM `$table` WHERE stat_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $stat_id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get stat value
         *
         * @param  int    $page_id
         * @param  string $type
         * @return array
         */
        public function get_stat_value( $page_id, $type )
        {
            $count = 0;
            if ( $stat = $this->get_stat_bypage( $page_id )) {
                if ( isset( $stat->$type )) {
                    $count = (int)$stat->$type;
                }
            }
            return $count;
        }
        
        /**
         * Get stat by page
         *
         * @param  int $page_id
         * @return array
         */
        public function get_stat_bypage( $page_id )
        {
            global $wpdb;
            
            $page_id = absint( $page_id );
            $table   = $wpdb->prefix . 'ipcpop_stats';
            $sql     = "
                SELECT 
                    SUM( `stat_view` ) AS `view`,
                    SUM( `stat_subscribe` ) AS `subscribe`,
                    SUM( `stat_buy` ) AS `buy`,
                    SUM( `stat_social` ) AS `social`
                FROM `$table` WHERE page_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $page_id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get stat by page date
         *
         * @param  int    $page_id
         * @param  string $date
         * @return array
         */
        public function get_stat_bypage_date( $page_id, $date )
        {
            global $wpdb;
            
            $page_id = absint( $page_id );
            $table   = $wpdb->prefix . 'ipcpop_stats';
            $sql     = "
                SELECT *
                FROM `$table` 
                WHERE page_id = $page_id and stat_date = '$date'
            ";
            $results = $wpdb->get_row( $sql );
            return $results;
        }
        
        /**
         * Get statistic data
         *
         * @return array
         */
        public function get_statistic_data( $page_id, $type, $start = null, $end = null )
        {
            global $wpdb;
            
            $page_id = absint( $page_id );
            $table   = $wpdb->prefix . 'ipcpop_stats';
            $query   = "
                SELECT 
                    DATE_FORMAT(stat_date, '%Y-%m-%d') AS gdate,";
            //Type value
            if ( $type == 'view' ) {
                $query .= 'SUM(stat_view) AS value';
            } elseif ( $type == 'subscribe' ) {
                $query .= 'SUM(stat_subscribe) AS value';
            } elseif ( $type == 'buy' ) {
                $query .= 'SUM(stat_buy) AS value';
            } elseif ( $type == 'social' ) {
                $query .= 'SUM(stat_social) AS value';
            }
            $query .= " FROM $table
                        WHERE page_id = $page_id";
            
            if ( ! empty( $start ) && ! empty( $end )) 
            {
                if ( $start == $end ) {
                    $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
                } else {
                    $query .= " AND stat_date BETWEEN '$start' AND '$end'";
                }
            }
            elseif ( ! empty( $start )) {
                $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
            }
            elseif ( ! empty( $end )) {
                $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$end'";
            }
            $query .= " GROUP BY gdate";
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Do save statistic
         *
         * @param object $page
         * @param string $type
         * @param int    $count
         * @return void
         */
        public function save_stat( $page, $type, $count = 1 )
        {
            $_types = array(
                'view',
                'subscribe',
                'buy',
                'social'
            );
            $key = 'stat_';
            if ( in_array( $type, $_types )) {
                $key .= $type;
            }
            $date = date( 'Y-m-d 00:00:00' );
            $data = array();
            if ( $stat = $this->get_stat_bypage_date( $page->ID, $date )) 
            {
                $ccount = 0;
                if ( isset( $stat->$key )) {
                    $ccount = $stat->$key;
                }
                $data[$key] = $ccount + $count;
                $this->_update_stat( $stat->stat_id, $data );
            }
            else {
                $data['page_id']   = $page->ID;
                $data['stat_date'] = $date;
                $data[$key]        = $count;
                $this->_insert_stat( $data );
            }
        }
        
        /**
         * Insert statistic data
         *
         * @param array $data
         * @return void
         */
        protected function _insert_stat( $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'ipcpop_stats';
            $data   = (array)$data;
            
            $result = $wpdb->insert( $table, $data );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update statistic data
         *
         * @param int   $id
         * @param array $data
         * @return void
         */
        protected function _update_stat( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'ipcpop_stats';
            $data   = (array)$data;
            $where  = array(
                'stat_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
    }

}
?>