<?php
/*
Plugin Name: WP Popper Pro
Plugin URI: 
Description: Plugin that is used to create a content that poping up when user scroll page down
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPCPOP_TITLE', 'WP Popper Pro' );
define( 'IPCPOP_FILE', __FILE__ );
define( 'IPCPOP_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPCPOP_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPCPOP_PATH . "app/config.php" );
require_once( IPCPOP_PATH . "app/setting.php" );
require_once( IPCPOP_PATH . "app/db.php" );
require_once( IPCPOP_PATH . "app/font.php" );
require_once( IPCPOP_PATH . "app/form.php" );
require_once( IPCPOP_PATH . "app/ajax.php" );
require_once( IPCPOP_PATH . "app/admin.php" );
require_once( IPCPOP_PATH . "app/model.php" );
require_once( IPCPOP_PATH . "app/shortcode.php" );

/**
 * Main class
 */
if ( ! class_exists( 'IPCpop' )) {

    class IPCpop
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPCPOP_TITLE );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );
            
            //Plugin init
            add_action( 'init', array( __CLASS__, 'i18n' ) );
            
            //Plugin admin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //
            //Editor button & Shortcode
            
            //Add Editor Button
            add_action( 'admin_init', array( __CLASS__, 'add_editor_button' ) );
            
            //Add Editor Dialog
            add_action( 'tiny_mce_preload_dialogs', array( __CLASS__, 'create_editor' ) );
            add_action( 'after_wp_tiny_mce', array( __CLASS__, 'create_editor' ) );
            
            //Add Shortcode
            add_shortcode( 'popper_pro', array( __CLASS__, 'shortcode' ) );
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'style_admin_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_ipcpop', array( __CLASS__, 'style_admin' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipcpop-create', array( __CLASS__, 'style_admin' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipcpop-setting', array( __CLASS__, 'style_admin' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_ipcpop', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipcpop-create', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipcpop-setting', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'global_script_admin' ), 1100 );
            
            
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'public_style' ) );
            
            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'public_script' ), 10 );
            }
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Install DB
            $db = new IPCpop_Db();
            $db->install();
        }
        
        /**
         * Update Db
         *
         * @return void
         */
        public static function updateDb()
        {
            $db = new IPCpop_Db();
            $db->update();
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPCPOP_TITLE, 
                IPCPOP_TITLE, 
                'ipcpop_manage', 
                'ipcpop',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipcpop',
                __( 'All Contents', 'wp-popper-pro' ), 
                __( 'All Contents', 'wp-popper-pro' ), 
                'ipcpop_manage', 
                'ipcpop',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipcpop',
                __( 'Add New Content', 'wp-popper-pro' ), 
                __( 'Add New Content', 'wp-popper-pro' ), 
                'ipcpop_manage', 
                'ipcpop-create',
                array( __CLASS__, 'admin_create' )
            );
        }
        
        /**
         * Handle internationalization
         *
         * @return void
         */
        public static function i18n()
        {
            load_plugin_textdomain( 'wp-popper-pro', false, basename( IPCPOP_PATH ) . '/languages/' );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipcpop_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPCpop_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPCpop_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'update' ) {
                $display->update();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator group
         *
         * @return void
         */
        public static function admin_create()
        {
            $display = new IPCpop_Admin();
            $display->create();
        }
        
        /**
         * Main method for parse content shortcode
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public static function shortcode( $atts, $content = '')
        {
            $factory = new IPCpop_Shortcode();
            return $factory->render( $atts, $content );
        }
         
        /**
         * Hook function for add button to editor
         *
         * @return void
         */
        public static function add_editor_button() 
        {
            if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
                return;
            }
            if ( get_user_option('rich_editing') == 'true') {
                add_filter( 'mce_external_plugins', array( __CLASS__, 'add_tinymce_plugin' ));
                add_filter( 'mce_buttons', array( __CLASS__, 'register_tinymce_button' ));
            }
        }

        /**
         * Register button to TinyMce system
         *
         * @param  array $button
         * @return void
         */
        public static function register_tinymce_button( $buttons ) 
        {
           array_push($buttons, "|", "ipcpopsc");
           return $buttons;
        }

        /**
         * Register TinyMce plugin
         *
         * @param  array $plugin_array
         * @return void
         */
        public static function add_tinymce_plugin( $plugin_array ) 
        {
           $plugin_array['ipcpopsc'] = plugin_dir_url( __FILE__ ) . 'js/editor.js';
           return $plugin_array;
        }
        
        /**
         * Content editor dialog
         *
         * @return void
         */
        public static function create_editor()
        {
            $display = new IPCpop_Shortcode();
            $display->editor();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function style_admin()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('ipcpop-admin-style');
            wp_register_style('ipcpop-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipcpop-admin-style');
            
            wp_deregister_style('ipcpop-public-style');
            wp_register_style('ipcpop-public-style', plugin_dir_url( __FILE__ ) . 'css/public.css', false, null);
            wp_enqueue_style('ipcpop-public-style');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function style_admin_global()
        {
            wp_deregister_style('ipcpop-admin-style-global');
            wp_register_style('ipcpop-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('ipcpop-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function script_admin($hook)
        {
        ?>
        <script type="text/javascript">
            var ipcpop_img_url  = '<?php echo IPCPOP_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPCPOP_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp-popper-pro' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp-popper-pro' ); ?>'
                },
                ipcpop_favicon_base = '<?php echo IPCPOP_BASE_URL . 'img/favicon/'; ?>';
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipcpop-admin-script');
            wp_enqueue_script(
                'ipcpop-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function global_script_admin($hook)
        {
            wp_deregister_script('ipcpop-admin-global-script');
            wp_enqueue_script(
                'ipcpop-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            $fonts = array( 'roboto' );
            //
            //Get all contents
            $args = array(
                'orderby'        => 'post_title',
                'order'          => 'DESC', 
                'post_type'      => 'ipcpop-item',
                'post_status'    => array('publish'),
                'posts_per_page' => -1,
                'paged'          => 1
            );
            $query = new WP_Query;
            $contents = $query->query( $args );
            foreach( $contents as $content ) 
            {
                $setting = new IPCpop_Setting( $content->ID, '__ipcpop-setting' );
                $fonts[] = $setting->getSetting( 'font_family', 'roboto' );
                $fonts[] = $setting->getSetting( 'form_font_family', 'roboto' );
                $fonts[] = $setting->getSetting( 'box_font_family', 'roboto' );
            }
            $fonts = array_unique( $fonts );
            $fams  = array();
            
            $links = IPCpop_Font::getLinks();
            foreach( $fonts as $font ) 
            {
                if ( array_key_exists( $font, $links )) 
                {
                    $fams[] = $links[$font];
                }
            }
            $families = implode( '|', $fams );
            
            $fontUrl = 'http://fonts.googleapis.com/css?family=' . $families;
            echo '<link id="ipcpop-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
        ?>
            <script type="text/javascript">
                var ipcpop_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('ipcpop-public-script');
            wp_enqueue_script(
                'ipcpop-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPCpop::setup();
?>